@@ -9,6 +9,7 @@
 
 #include "models/completionmodel.h"
 #include "models/userlistmodel.h"
+#include "neochatroom.h"
 
 class QTextDocument;
 class NeoChatRoom;
@@ -17,6 +18,14 @@ class SyntaxHighlighter;
 class ChatDocumentHandler : public QObject
 {
     Q_OBJECT
+
+    /**
+     * @brief Is the instance being used to handle an edit message.
+     *
+     * This is needed to ensure that the text and mentions are saved and retrieved
+     * from the correct parameters in the assigned room.
+     */
+    Q_PROPERTY(bool isEdit READ isEdit WRITE setIsEdit NOTIFY isEditChanged)
     Q_PROPERTY(QQuickTextDocument *document READ document WRITE setDocument NOTIFY documentChanged)
     Q_PROPERTY(int cursorPosition READ cursorPosition WRITE setCursorPosition NOTIFY cursorPositionChanged)
     Q_PROPERTY(int selectionStart READ selectionStart WRITE setSelectionStart NOTIFY selectionStartChanged)
@@ -24,11 +33,14 @@ class ChatDocumentHandler : public QObject
 
     Q_PROPERTY(CompletionModel *completionModel READ completionModel NOTIFY completionModelChanged)
 
-    Q_PROPERTY(NeoChatRoom *room READ room NOTIFY roomChanged)
+    Q_PROPERTY(NeoChatRoom *room READ room WRITE setRoom NOTIFY roomChanged)
 
 public:
     explicit ChatDocumentHandler(QObject *parent = nullptr);
 
+    [[nodiscard]] bool isEdit() const;
+    void setIsEdit(bool edit);
+
     [[nodiscard]] QQuickTextDocument *document() const;
     void setDocument(QQuickTextDocument *document);
 
@@ -49,6 +61,7 @@ public:
     void updateCompletions();
     CompletionModel *completionModel() const;
 Q_SIGNALS:
+    void isEditChanged();
     void documentChanged();
     void cursorPositionChanged();
     void roomChanged();
@@ -59,6 +72,8 @@ Q_SIGNALS:
 private:
     int completionStartIndex() const;
 
+    bool m_isEdit;
+
     QQuickTextDocument *m_document;
 
     NeoChatRoom *m_room = nullptr;
@@ -68,6 +83,9 @@ private:
     int m_selectionStart;
     int m_selectionEnd;
 
+    QString getText() const;
+    void pushMention(const Mention mention) const;
+
     SyntaxHighlighter *m_highlighter = nullptr;
 
     CompletionModel::AutoCompletionType m_completionType = CompletionModel::None;
