@@ -1,10 +1,14 @@
 // SPDX-FileCopyrightText: 2018-2019 Black Hat <bhat@encom.eu.org>
-// SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+// SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "controller.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -37,6 +41,7 @@
 #include <csapi/content-repo.h>
 #include <csapi/logout.h>
 #include <csapi/profile.h>
+#include <jobs/downloadfilejob.h>
 #include <qt_connection_util.h>
 
 #ifdef QUOTIENT_07
@@ -165,7 +170,9 @@ void Controller::handleNotifications(QPointer<Quotient::Connection> connection)
             auto room = connection->room(notification["room_id"].toString());
 
             // If room exists, room is NOT active OR the application is NOT active, show notification
-            if (room && !(room->id() == RoomManager::instance().currentRoom()->id() && QGuiApplication::applicationState() == Qt::ApplicationActive)) {
+            if (room
+                && !(RoomManager::instance().currentRoom() && room->id() == RoomManager::instance().currentRoom()->id()
+                     && QGuiApplication::applicationState() == Qt::ApplicationActive)) {
                 // The room might have been deleted (for example rejected invitation).
                 auto sender = room->user(notification["event"].toObject()["sender"].toString());
 
@@ -604,6 +611,11 @@ void Controller::setActiveConnection(Connection *connection)
             m_isOnline = true;
             Q_EMIT isOnlineChanged(true);
         });
+        connect(connection, &Connection::requestFailed, this, [=](BaseJob *job) {
+            if (dynamic_cast<DownloadFileJob *>(job) && job->jsonData()["errcode"].toString() == "M_TOO_LARGE"_ls) {
+                RoomManager::instance().warning(i18n("File too large to download."), i18n("Contact your matrix server administrator for support."));
+            }
+        });
     } else {
         NeoChatConfig::self()->setActiveConnection(QString());
     }
@@ -632,9 +644,17 @@ NeochatDeleteDeviceJob::NeochatDeleteDeviceJob(const QString &deviceId, const Om
 void Controller::createRoom(const QString &name, const QString &topic)
 {
     auto createRoomJob = m_connection->createRoom(Connection::PublishRoom, "", name, topic, QStringList());
-    Quotient::CreateRoomJob::connect(createRoomJob, &CreateRoomJob::failure, [this, createRoomJob] {
+    connect(createRoomJob, &CreateRoomJob::failure, this, [this, createRoomJob] {
         Q_EMIT errorOccured(i18n("Room creation failed: \"%1\"", createRoomJob->errorString()));
     });
+    connectSingleShot(
+        this,
+        &Controller::roomAdded,
+        this,
+        [this](NeoChatRoom *room) {
+            RoomManager::instance().enterRoom(room);
+        },
+        Qt::QueuedConnection);
 }
 
 bool Controller::isOnline() const
