@@ -45,6 +45,7 @@ public:
         AnnotationRole,
         UserMarkerRole,
         FormattedBodyRole,
+        GenericDisplayRole,
 
         MimeTypeRole,
         FileMimetypeIcon,
@@ -56,6 +57,9 @@ public:
         ShowAuthorRole,
         ShowSectionRole,
 
+        ReadMarkersRole, /**< QVariantList of users at the event for read marker tracking. */
+        ReadMarkersStringRole, /**< QString with the display name and mxID of the users at the event. */
+        ShowReadMarkersRole, /**< bool with whether there are any other user read markers to be shown. */
         ReactionRole,
 
         IsEditedRole,
@@ -69,9 +73,8 @@ public:
         DisplayNameForInitialsRole,
         // The displayname for the event's sender; for name change events, the old displayname
         AuthorDisplayNameRole,
-        IsNameChangeRole,
-        IsAvatarChangeRole,
         IsRedactedRole,
+        IsPendingRole,
         LastRole, // Keep this last
     };
     Q_ENUM(EventRoles)
